#!/bin/bash

filetime="$(date +%m%d%H%M%S)"
SUDO=`which sudo`
INSTALL=`which install`
ROOT_INSTALL=$INSTALL' -o root -g root'

echo "Stopping running process of gPen, gCal, gDraw utilities."
$SUDO killall -q gDraw gCal gPen

echo "Check xorg config file."
ls /etc/X11/xorg.conf
if [ $? != 0 ]; then
    random_display=$RANDOM
    echo 'use random display : ' $random_display
    $SUDO /usr/bin/Xorg -configure :$random_display
    if [ $? != 0 ]; then
        $SUDO $ROOT_INSTALL xorg.conf /etc/X11/xorg.conf
    else
        $SUDO mv ~/xorg.conf.new /etc/X11/xorg.conf
    fi
    $SUDO rm -f /tmp/X11-lock/X$random_display
else
    $SUDO cp /etc/X11/xorg.conf /etc/X11/xorg.conf.$filetime
fi

echo "Copy applications..."
$SUDO $ROOT_INSTALL pm-setup         /usr/sbin
$SUDO $ROOT_INSTALL gCal             /usr/sbin
$SUDO $ROOT_INSTALL gDraw            /usr/sbin
$SUDO $ROOT_INSTALL gPen             /usr/sbin
$SUDO $ROOT_INSTALL -m 4755 gPen-wrapper     /usr/sbin
$SUDO $ROOT_INSTALL -m 4755 gCal-wrapper     /usr/sbin

echo "Copy resource files..."
$SUDO mkdir -p /usr/share/penmount
$SUDO $ROOT_INSTALL penmount.png     /usr/share/penmount
$SUDO $ROOT_INSTALL README /usr/share/penmount

$SUDO $ROOT_INSTALL penmount.dat     /etc
$SUDO $ROOT_INSTALL penmount48.png   /usr/share/pixmaps/penmount.png
$SUDO $ROOT_INSTALL penmount48.png   /usr/share/icons/gnome/48x48/apps/penmount.png
$SUDO $ROOT_INSTALL penmount32.png   /usr/share/icons/gnome/32x32/apps/penmount.png
$SUDO $ROOT_INSTALL penmount24.png   /usr/share/icons/gnome/24x24/apps/penmount.png
$SUDO $ROOT_INSTALL penmount22.png   /usr/share/icons/gnome/22x22/apps/penmount.png
$SUDO $ROOT_INSTALL penmount16.png   /usr/share/icons/gnome/16x16/apps/penmount.png
$SUDO $ROOT_INSTALL penmount.desktop /usr/share/applications

if [ -f /usr/share/gnome-menus/update-gnome-menus-cache ]
then
/usr/share/gnome-menus/update-gnome-menus-cache /usr/share/applications > ~/desktop.en_US.utf8.cache
$SUDO mv ~/desktop.en_US.utf8.cache /usr/share/applications/desktop.en_US.utf8.cache
fi

$SUDO chmod 777 ~/.config/autostart
if [ ! -d ~/.config/autostart ]
then
mkdir -p ~/.config/autostart
fi
$INSTALL penmount_autostart.desktop ~/.config/autostart/penmount.desktop
$SUDO chmod 755 ~/.config/autostart

echo "Penmount detection and /etc/X11/xorg.conf parsing/writing..."
$SUDO /usr/sbin/pm-setup -s

echo "Remove old penmount_drv.so"
$SUDO find /usr/lib/xorg/modules/ -name penmount_drv.so -type f -delete

echo "Copy Xorg module drivers..."
$SUDO $ROOT_INSTALL penmount_drv.so  /usr/lib/xorg/modules/input

echo "Please logout and re-login to use Penmount device."
